@@ -1,7 +1,6 @@
 """
 Wrapper for `git diff` command.
 """
-from __future__ import unicode_literals
 
 from diff_cover.command_runner import execute
 
@@ -10,15 +9,16 @@ class GitDiffError(Exception):
     """
     `git diff` command produced an error.
     """
+
     pass
 
 
-class GitDiffTool(object):
+class GitDiffTool:
     """
     Thin wrapper for a subset of the `git diff` command.
     """
 
-    def __init__(self, range_notation):
+    def __init__(self, range_notation, ignore_whitespace):
         """
         :param str range_notation:
             which range notation to use when producing the diff for committed
@@ -33,10 +33,26 @@ class GitDiffTool(object):
             describes the actual patch that will be applied by merging A into M, even if commits have been
             cherry-picked between branches. This will produce a more accurate diff for coverage comparison when
             complex merges and cherry-picks are involved.
+
+         :param bool ignore_whitespace:
+            Perform a diff but ignore any and all whitespace.
         """
         self._range_notation = range_notation
+        self._default_git_args = [
+            "git",
+            "-c",
+            "diff.mnemonicprefix=no",
+            "-c",
+            "diff.noprefix=no",
+        ]
 
-    def diff_committed(self, compare_branch='origin/master'):
+        self._default_diff_args = ["diff", "--no-color", "--no-ext-diff", "-U0"]
+
+        if ignore_whitespace:
+            self._default_diff_args.append("--ignore-all-space")
+            self._default_diff_args.append("--ignore-blank-lines")
+
+    def diff_committed(self, compare_branch="origin/master"):
         """
         Returns the output of `git diff` for committed
         changes not yet in origin/master.
@@ -44,15 +60,12 @@ class GitDiffTool(object):
         Raises a `GitDiffError` if `git diff` outputs anything
         to stderr.
         """
-        return execute([
-            'git',
-            '-c', 'diff.mnemonicprefix=no',
-            '-c', 'diff.noprefix=no',
-            'diff', '{branch}{notation}HEAD'.format(branch=compare_branch, notation=self._range_notation),
-            '--no-color',
-            '--no-ext-diff',
-            '-U0'
-        ])[0]
+        diff_range = "{branch}{notation}HEAD".format(
+            branch=compare_branch, notation=self._range_notation
+        )
+        return execute(self._default_git_args + self._default_diff_args + [diff_range])[
+            0
+        ]
 
     def diff_unstaged(self):
         """
@@ -62,15 +75,7 @@ class GitDiffTool(object):
         Raises a `GitDiffError` if `git diff` outputs anything
         to stderr.
         """
-        return execute([
-            'git',
-            '-c', 'diff.mnemonicprefix=no',
-            '-c', 'diff.noprefix=no',
-            'diff',
-            '--no-color',
-            '--no-ext-diff',
-            '-U0'
-        ])[0]
+        return execute(self._default_git_args + self._default_diff_args)[0]
 
     def diff_staged(self):
         """
@@ -80,13 +85,6 @@ class GitDiffTool(object):
         Raises a `GitDiffError` if `git diff` outputs anything
         to stderr.
         """
-        return execute([
-            'git',
-            '-c', 'diff.mnemonicprefix=no',
-            '-c', 'diff.noprefix=no',
-            'diff',
-            '--cached',
-            '--no-color',
-            '--no-ext-diff',
-            '-U0'
-        ])[0]
+        return execute(self._default_git_args + self._default_diff_args + ["--cached"])[
+            0
+        ]
