@@ -4,6 +4,7 @@ in HTML reports.
 """
 import pygments
 from pygments.formatters.html import HtmlFormatter
+from pygments.formatters.terminal import TerminalFormatter
 from pygments.lexers import guess_lexer_for_filename
 from pygments.lexers.special import TextLexer
 from pygments.util import ClassNotFound
@@ -30,7 +31,23 @@ class Snippet:
     # should split into two snippets.
     MAX_GAP_IN_SNIPPET = 4
 
-    def __init__(self, src_tokens, src_filename, start_line, violation_lines):
+    # See https://github.com/github/linguist/blob/master/lib/linguist/languages.yml
+    # for typical values of accepted programming language hints in Markdown code fenced blocks
+    LEXER_TO_MARKDOWN_CODE_HINT = {
+        "Python": "python",
+        "C++": "cpp",
+        # TODO: expand this list...
+    }
+
+    def __init__(
+        self,
+        src_tokens,
+        src_filename,
+        start_line,
+        last_line,
+        violation_lines,
+        lexer_name,
+    ):
         """
         Create a source code snippet.
 
@@ -45,9 +62,16 @@ class Snippet:
         in `src_str`.  The first line in the file is
         line number 1.
 
+        `last_line` is the line number of last line
+        in `src_str`.
+
         `violation_lines` is a list of line numbers
         to highlight as violations.
 
+        `lexer_name` provides an hint on the
+        programming language for this snippet.
+        See https://pygments.org/docs/lexers/
+
         Raises a `ValueError` if `start_line` is less than 1
         """
         if start_line < 1:
@@ -56,7 +80,9 @@ class Snippet:
         self._src_tokens = src_tokens
         self._src_filename = src_filename
         self._start_line = start_line
+        self._last_line = last_line
         self._violation_lines = violation_lines
+        self._lexer_name = lexer_name
 
     @classmethod
     def style_defs(cls):
@@ -82,6 +108,36 @@ class Snippet:
 
         return pygments.format(self.src_tokens(), formatter)
 
+    def markdown(self):
+        """
+        Return a Markdown representation of the snippet using Markdown fenced code blocks.
+        See https://github.github.com/gfm/#fenced-code-blocks.
+        """
+        header = "Lines %d-%d\n\n" % (self._start_line, self._last_line)
+        if self._lexer_name in self.LEXER_TO_MARKDOWN_CODE_HINT:
+            return header + (
+                "```"
+                + self.LEXER_TO_MARKDOWN_CODE_HINT[self._lexer_name]
+                + "\n"
+                + self.text()
+                + "\n```\n"
+            )
+
+        # unknown programming language, return a non-decorated fenced code block:
+        return "```\n" + self.text() + "\n```\n"
+
+    def terminal(self):
+        """
+        Return a Terminal-friendly (with ANSI color sequences) representation of the snippet.
+        """
+        formatter = TerminalFormatter(
+            linenos=True,
+            colorscheme=None,
+            linenostart=self._start_line,
+        )
+
+        return pygments.format(self.src_tokens(), formatter)
+
     def src_tokens(self):
         """
         Return a list of `(token_type, value)` tokens
@@ -105,15 +161,24 @@ class Snippet:
         return "".join([val for _, val in self._src_tokens])
 
     @classmethod
-    def load_snippets_html(cls, src_path, violation_lines):
+    def load_formatted_snippets(cls, src_path, violation_lines):
         """
         Load snippets from the file at `src_path` and format
-        them as HTML.
+        them as HTML and as plain text.
+        Returns a dictionary containing the two types of formatting
+        results for code snippets.
 
         See `load_snippets()` for details.
         """
+
+        # load once...
         snippet_list = cls.load_snippets(src_path, violation_lines)
-        return [snippet.html() for snippet in snippet_list]
+
+        # ...render twice in different formats
+        return {
+            "html": [snippet.html() for snippet in snippet_list],
+            "markdown": [snippet.markdown() for snippet in snippet_list],
+        }
 
     @classmethod
     def load_snippets(cls, src_path, violation_lines):
@@ -141,14 +206,14 @@ class Snippet:
         snippet_ranges = cls._snippet_ranges(len(src_lines), violation_lines)
 
         # Parse the source into tokens
-        token_stream = cls._parse_src(contents, src_path)
+        token_stream, lexer = cls._parse_src(contents, src_path)
 
         # Group the tokens by snippet
         token_groups = cls._group_tokens(token_stream, snippet_ranges)
 
         return [
-            Snippet(tokens, src_path, start, violation_lines)
-            for (start, _), tokens in sorted(token_groups.items())
+            Snippet(tokens, src_path, start, end, violation_lines, lexer.name)
+            for (start, end), tokens in sorted(token_groups.items())
         ]
 
     @classmethod
@@ -171,7 +236,7 @@ class Snippet:
         # the source file when lexing.
         lexer.stripnl = False
 
-        return pygments.lex(src_contents, lexer)
+        return pygments.lex(src_contents, lexer), lexer
 
     @classmethod
     def _group_tokens(cls, token_stream, range_list):
